# coding: utf-8

"""
    Phrase Strings API Reference

    The version of the OpenAPI document: 2.0.0
    Contact: support@phrase.com
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from phrase_api.configuration import Configuration


class StyleguideDetails1(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'public_url': 'str',
        'audience': 'str',
        'target_audience': 'str',
        'grammatical_person': 'str',
        'vocabulary_type': 'str',
        'business': 'str',
        'company_branding': 'str',
        'formatting': 'str',
        'glossary_terms': 'str',
        'grammar_consistency': 'str',
        'literal_translation': 'str',
        'overall_tone': 'str',
        'samples': 'str'
    }

    attribute_map = {
        'public_url': 'public_url',
        'audience': 'audience',
        'target_audience': 'target_audience',
        'grammatical_person': 'grammatical_person',
        'vocabulary_type': 'vocabulary_type',
        'business': 'business',
        'company_branding': 'company_branding',
        'formatting': 'formatting',
        'glossary_terms': 'glossary_terms',
        'grammar_consistency': 'grammar_consistency',
        'literal_translation': 'literal_translation',
        'overall_tone': 'overall_tone',
        'samples': 'samples'
    }

    def __init__(self, public_url=None, audience=None, target_audience=None, grammatical_person=None, vocabulary_type=None, business=None, company_branding=None, formatting=None, glossary_terms=None, grammar_consistency=None, literal_translation=None, overall_tone=None, samples=None, local_vars_configuration=None):  # noqa: E501
        """StyleguideDetails1 - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._public_url = None
        self._audience = None
        self._target_audience = None
        self._grammatical_person = None
        self._vocabulary_type = None
        self._business = None
        self._company_branding = None
        self._formatting = None
        self._glossary_terms = None
        self._grammar_consistency = None
        self._literal_translation = None
        self._overall_tone = None
        self._samples = None
        self.discriminator = None

        if public_url is not None:
            self.public_url = public_url
        if audience is not None:
            self.audience = audience
        if target_audience is not None:
            self.target_audience = target_audience
        if grammatical_person is not None:
            self.grammatical_person = grammatical_person
        if vocabulary_type is not None:
            self.vocabulary_type = vocabulary_type
        if business is not None:
            self.business = business
        if company_branding is not None:
            self.company_branding = company_branding
        if formatting is not None:
            self.formatting = formatting
        if glossary_terms is not None:
            self.glossary_terms = glossary_terms
        if grammar_consistency is not None:
            self.grammar_consistency = grammar_consistency
        if literal_translation is not None:
            self.literal_translation = literal_translation
        if overall_tone is not None:
            self.overall_tone = overall_tone
        if samples is not None:
            self.samples = samples

    @property
    def public_url(self):
        """Gets the public_url of this StyleguideDetails1.  # noqa: E501


        :return: The public_url of this StyleguideDetails1.  # noqa: E501
        :rtype: str
        """
        return self._public_url

    @public_url.setter
    def public_url(self, public_url):
        """Sets the public_url of this StyleguideDetails1.


        :param public_url: The public_url of this StyleguideDetails1.  # noqa: E501
        :type: str
        """

        self._public_url = public_url

    @property
    def audience(self):
        """Gets the audience of this StyleguideDetails1.  # noqa: E501


        :return: The audience of this StyleguideDetails1.  # noqa: E501
        :rtype: str
        """
        return self._audience

    @audience.setter
    def audience(self, audience):
        """Sets the audience of this StyleguideDetails1.


        :param audience: The audience of this StyleguideDetails1.  # noqa: E501
        :type: str
        """

        self._audience = audience

    @property
    def target_audience(self):
        """Gets the target_audience of this StyleguideDetails1.  # noqa: E501


        :return: The target_audience of this StyleguideDetails1.  # noqa: E501
        :rtype: str
        """
        return self._target_audience

    @target_audience.setter
    def target_audience(self, target_audience):
        """Sets the target_audience of this StyleguideDetails1.


        :param target_audience: The target_audience of this StyleguideDetails1.  # noqa: E501
        :type: str
        """

        self._target_audience = target_audience

    @property
    def grammatical_person(self):
        """Gets the grammatical_person of this StyleguideDetails1.  # noqa: E501


        :return: The grammatical_person of this StyleguideDetails1.  # noqa: E501
        :rtype: str
        """
        return self._grammatical_person

    @grammatical_person.setter
    def grammatical_person(self, grammatical_person):
        """Sets the grammatical_person of this StyleguideDetails1.


        :param grammatical_person: The grammatical_person of this StyleguideDetails1.  # noqa: E501
        :type: str
        """

        self._grammatical_person = grammatical_person

    @property
    def vocabulary_type(self):
        """Gets the vocabulary_type of this StyleguideDetails1.  # noqa: E501


        :return: The vocabulary_type of this StyleguideDetails1.  # noqa: E501
        :rtype: str
        """
        return self._vocabulary_type

    @vocabulary_type.setter
    def vocabulary_type(self, vocabulary_type):
        """Sets the vocabulary_type of this StyleguideDetails1.


        :param vocabulary_type: The vocabulary_type of this StyleguideDetails1.  # noqa: E501
        :type: str
        """

        self._vocabulary_type = vocabulary_type

    @property
    def business(self):
        """Gets the business of this StyleguideDetails1.  # noqa: E501


        :return: The business of this StyleguideDetails1.  # noqa: E501
        :rtype: str
        """
        return self._business

    @business.setter
    def business(self, business):
        """Sets the business of this StyleguideDetails1.


        :param business: The business of this StyleguideDetails1.  # noqa: E501
        :type: str
        """

        self._business = business

    @property
    def company_branding(self):
        """Gets the company_branding of this StyleguideDetails1.  # noqa: E501


        :return: The company_branding of this StyleguideDetails1.  # noqa: E501
        :rtype: str
        """
        return self._company_branding

    @company_branding.setter
    def company_branding(self, company_branding):
        """Sets the company_branding of this StyleguideDetails1.


        :param company_branding: The company_branding of this StyleguideDetails1.  # noqa: E501
        :type: str
        """

        self._company_branding = company_branding

    @property
    def formatting(self):
        """Gets the formatting of this StyleguideDetails1.  # noqa: E501


        :return: The formatting of this StyleguideDetails1.  # noqa: E501
        :rtype: str
        """
        return self._formatting

    @formatting.setter
    def formatting(self, formatting):
        """Sets the formatting of this StyleguideDetails1.


        :param formatting: The formatting of this StyleguideDetails1.  # noqa: E501
        :type: str
        """

        self._formatting = formatting

    @property
    def glossary_terms(self):
        """Gets the glossary_terms of this StyleguideDetails1.  # noqa: E501


        :return: The glossary_terms of this StyleguideDetails1.  # noqa: E501
        :rtype: str
        """
        return self._glossary_terms

    @glossary_terms.setter
    def glossary_terms(self, glossary_terms):
        """Sets the glossary_terms of this StyleguideDetails1.


        :param glossary_terms: The glossary_terms of this StyleguideDetails1.  # noqa: E501
        :type: str
        """

        self._glossary_terms = glossary_terms

    @property
    def grammar_consistency(self):
        """Gets the grammar_consistency of this StyleguideDetails1.  # noqa: E501


        :return: The grammar_consistency of this StyleguideDetails1.  # noqa: E501
        :rtype: str
        """
        return self._grammar_consistency

    @grammar_consistency.setter
    def grammar_consistency(self, grammar_consistency):
        """Sets the grammar_consistency of this StyleguideDetails1.


        :param grammar_consistency: The grammar_consistency of this StyleguideDetails1.  # noqa: E501
        :type: str
        """

        self._grammar_consistency = grammar_consistency

    @property
    def literal_translation(self):
        """Gets the literal_translation of this StyleguideDetails1.  # noqa: E501


        :return: The literal_translation of this StyleguideDetails1.  # noqa: E501
        :rtype: str
        """
        return self._literal_translation

    @literal_translation.setter
    def literal_translation(self, literal_translation):
        """Sets the literal_translation of this StyleguideDetails1.


        :param literal_translation: The literal_translation of this StyleguideDetails1.  # noqa: E501
        :type: str
        """

        self._literal_translation = literal_translation

    @property
    def overall_tone(self):
        """Gets the overall_tone of this StyleguideDetails1.  # noqa: E501


        :return: The overall_tone of this StyleguideDetails1.  # noqa: E501
        :rtype: str
        """
        return self._overall_tone

    @overall_tone.setter
    def overall_tone(self, overall_tone):
        """Sets the overall_tone of this StyleguideDetails1.


        :param overall_tone: The overall_tone of this StyleguideDetails1.  # noqa: E501
        :type: str
        """

        self._overall_tone = overall_tone

    @property
    def samples(self):
        """Gets the samples of this StyleguideDetails1.  # noqa: E501


        :return: The samples of this StyleguideDetails1.  # noqa: E501
        :rtype: str
        """
        return self._samples

    @samples.setter
    def samples(self, samples):
        """Sets the samples of this StyleguideDetails1.


        :param samples: The samples of this StyleguideDetails1.  # noqa: E501
        :type: str
        """

        self._samples = samples

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, StyleguideDetails1):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, StyleguideDetails1):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Phrase Strings API Reference

    The version of the OpenAPI document: 2.0.0
    Contact: support@phrase.com
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest

import phrase_api
from phrase_api.api.members_api import MembersApi  # noqa: E501
from phrase_api.rest import ApiException


class TestMembersApi(unittest.TestCase):
    """MembersApi unit test stubs"""

    def setUp(self):
        self.api = phrase_api.api.members_api.MembersApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_member_delete(self):
        """Test case for member_delete

        Remove a user from the account  # noqa: E501
        """
        pass

    def test_member_show(self):
        """Test case for member_show

        Get single member  # noqa: E501
        """
        pass

    def test_member_update(self):
        """Test case for member_update

        Update a member  # noqa: E501
        """
        pass

    def test_member_update_settings(self):
        """Test case for member_update_settings

        Update a member's project settings  # noqa: E501
        """
        pass

    def test_members_list(self):
        """Test case for members_list

        List members  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Phrase Strings API Reference

    The version of the OpenAPI document: 2.0.0
    Contact: support@phrase.com
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import re  # noqa: F401

# python 2 and python 3 compatibility library
import six

from phrase_api.api_client import ApiClient
from phrase_api.exceptions import (  # noqa: F401
    ApiTypeError,
    ApiValueError
)


class UploadsApi(object):
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client

    def upload_create(self, project_id, **kwargs):  # noqa: E501
        """Upload a new file  # noqa: E501

        Upload a new language file. Creates necessary resources in your project.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.upload_create(project_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str project_id: Project ID (required)
        :param str x_phrase_app_otp: Two-Factor-Authentication token (optional)
        :param str branch: specify the branch to use
        :param file file: File to be imported
        :param str file_format: File format. Auto-detected when possible and not specified.
        :param str locale_id: Locale of the file's content. Can be the name or public id of the locale. Preferred is the public id.
        :param str tags: List of tags separated by comma to be associated with the new keys contained in the upload.
        :param bool update_translations: Indicates whether existing translations should be updated with the file content.
        :param bool update_descriptions: Existing key descriptions will be updated with the file content. Empty descriptions overwrite existing descriptions.
        :param bool convert_emoji: This option is obsolete. Providing the option will cause a bad request error.
        :param bool skip_upload_tags: Indicates whether the upload should not create upload tags.
        :param bool skip_unverification: Indicates whether the upload should unverify updated translations.
        :param str file_encoding: Enforces a specific encoding on the file contents. Valid options are \\\"UTF-8\\\", \\\"UTF-16\\\" and \\\"ISO-8859-1\\\".
        :param object locale_mapping: Optional, format specific mapping between locale names and the columns the translations to those locales are contained in.
        :param object format_options: Additional options available for specific formats. See our format guide for complete list.
        :param bool autotranslate: If set, translations for the uploaded language will be fetched automatically.
        :param bool mark_reviewed: Indicated whether the imported translations should be marked as reviewed. This setting is available if the review workflow (currently beta) is enabled for the project.
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: Upload
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.upload_create_with_http_info(project_id, **kwargs)  # noqa: E501

    def upload_create_with_http_info(self, project_id, **kwargs):  # noqa: E501
        """Upload a new file  # noqa: E501

        Upload a new language file. Creates necessary resources in your project.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.upload_create_with_http_info(project_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str project_id: Project ID (required)
        :param str x_phrase_app_otp: Two-Factor-Authentication token (optional)
        :param str branch: specify the branch to use
        :param file file: File to be imported
        :param str file_format: File format. Auto-detected when possible and not specified.
        :param str locale_id: Locale of the file's content. Can be the name or public id of the locale. Preferred is the public id.
        :param str tags: List of tags separated by comma to be associated with the new keys contained in the upload.
        :param bool update_translations: Indicates whether existing translations should be updated with the file content.
        :param bool update_descriptions: Existing key descriptions will be updated with the file content. Empty descriptions overwrite existing descriptions.
        :param bool convert_emoji: This option is obsolete. Providing the option will cause a bad request error.
        :param bool skip_upload_tags: Indicates whether the upload should not create upload tags.
        :param bool skip_unverification: Indicates whether the upload should unverify updated translations.
        :param str file_encoding: Enforces a specific encoding on the file contents. Valid options are \\\"UTF-8\\\", \\\"UTF-16\\\" and \\\"ISO-8859-1\\\".
        :param object locale_mapping: Optional, format specific mapping between locale names and the columns the translations to those locales are contained in.
        :param object format_options: Additional options available for specific formats. See our format guide for complete list.
        :param bool autotranslate: If set, translations for the uploaded language will be fetched automatically.
        :param bool mark_reviewed: Indicated whether the imported translations should be marked as reviewed. This setting is available if the review workflow (currently beta) is enabled for the project.
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(Upload, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'project_id',
            'x_phrase_app_otp',
            'branch',
            'file',
            'file_format',
            'locale_id',
            'tags',
            'update_translations',
            'update_descriptions',
            'convert_emoji',
            'skip_upload_tags',
            'skip_unverification',
            'file_encoding',
            'locale_mapping',
            'format_options',
            'autotranslate',
            'mark_reviewed'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method upload_create" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'project_id' is set
        if self.api_client.client_side_validation and ('project_id' not in local_var_params or  # noqa: E501
                                                        local_var_params['project_id'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `project_id` when calling `upload_create`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'project_id' in local_var_params:
            path_params['project_id'] = local_var_params['project_id']  # noqa: E501

        query_params = []

        header_params = {}
        if 'x_phrase_app_otp' in local_var_params:
            header_params['X-PhraseApp-OTP'] = local_var_params['x_phrase_app_otp']  # noqa: E501

        form_params = []
        local_var_files = {}
        if 'branch' in local_var_params:
            form_params.append(('branch', local_var_params['branch']))  # noqa: E501
        if 'file' in local_var_params:
            local_var_files['file'] = local_var_params['file']  # noqa: E501
        if 'file_format' in local_var_params:
            form_params.append(('file_format', local_var_params['file_format']))  # noqa: E501
        if 'locale_id' in local_var_params:
            form_params.append(('locale_id', local_var_params['locale_id']))  # noqa: E501
        if 'tags' in local_var_params:
            form_params.append(('tags', local_var_params['tags']))  # noqa: E501
        if 'update_translations' in local_var_params:
            form_params.append(('update_translations', local_var_params['update_translations']))  # noqa: E501
        if 'update_descriptions' in local_var_params:
            form_params.append(('update_descriptions', local_var_params['update_descriptions']))  # noqa: E501
        if 'convert_emoji' in local_var_params:
            form_params.append(('convert_emoji', local_var_params['convert_emoji']))  # noqa: E501
        if 'skip_upload_tags' in local_var_params:
            form_params.append(('skip_upload_tags', local_var_params['skip_upload_tags']))  # noqa: E501
        if 'skip_unverification' in local_var_params:
            form_params.append(('skip_unverification', local_var_params['skip_unverification']))  # noqa: E501
        if 'file_encoding' in local_var_params:
            form_params.append(('file_encoding', local_var_params['file_encoding']))  # noqa: E501
        if 'locale_mapping' in local_var_params:
            form_params.append(('locale_mapping', local_var_params['locale_mapping']))  # noqa: E501
        if 'format_options' in local_var_params:
            form_params.append(('format_options', local_var_params['format_options']))  # noqa: E501
        if 'autotranslate' in local_var_params:
            form_params.append(('autotranslate', local_var_params['autotranslate']))  # noqa: E501
        if 'mark_reviewed' in local_var_params:
            form_params.append(('mark_reviewed', local_var_params['mark_reviewed']))  # noqa: E501

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['multipart/form-data'])  # noqa: E501

        # Authentication setting
        auth_settings = ['Basic', 'Token']  # noqa: E501

        return self.api_client.call_api(
            '/projects/{project_id}/uploads', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='Upload',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def upload_show(self, project_id, id, **kwargs):  # noqa: E501
        """View upload details  # noqa: E501

        View details and summary for a single upload.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.upload_show(project_id, id, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str project_id: Project ID (required)
        :param str id: ID (required)
        :param str x_phrase_app_otp: Two-Factor-Authentication token (optional)
        :param str branch: specify the branch to use
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: Upload
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.upload_show_with_http_info(project_id, id, **kwargs)  # noqa: E501

    def upload_show_with_http_info(self, project_id, id, **kwargs):  # noqa: E501
        """View upload details  # noqa: E501

        View details and summary for a single upload.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.upload_show_with_http_info(project_id, id, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str project_id: Project ID (required)
        :param str id: ID (required)
        :param str x_phrase_app_otp: Two-Factor-Authentication token (optional)
        :param str branch: specify the branch to use
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(Upload, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'project_id',
            'id',
            'x_phrase_app_otp',
            'branch'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method upload_show" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'project_id' is set
        if self.api_client.client_side_validation and ('project_id' not in local_var_params or  # noqa: E501
                                                        local_var_params['project_id'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `project_id` when calling `upload_show`")  # noqa: E501
        # verify the required parameter 'id' is set
        if self.api_client.client_side_validation and ('id' not in local_var_params or  # noqa: E501
                                                        local_var_params['id'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `id` when calling `upload_show`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'project_id' in local_var_params:
            path_params['project_id'] = local_var_params['project_id']  # noqa: E501
        if 'id' in local_var_params:
            path_params['id'] = local_var_params['id']  # noqa: E501

        query_params = []
        if 'branch' in local_var_params and local_var_params['branch'] is not None:  # noqa: E501
            query_params.append(('branch', local_var_params['branch']))  # noqa: E501

        header_params = {}
        if 'x_phrase_app_otp' in local_var_params:
            header_params['X-PhraseApp-OTP'] = local_var_params['x_phrase_app_otp']  # noqa: E501

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['Basic', 'Token']  # noqa: E501

        return self.api_client.call_api(
            '/projects/{project_id}/uploads/{id}', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='Upload',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def uploads_list(self, project_id, **kwargs):  # noqa: E501
        """List uploads  # noqa: E501

        List all uploads for the given project.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.uploads_list(project_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str project_id: Project ID (required)
        :param str x_phrase_app_otp: Two-Factor-Authentication token (optional)
        :param int page: Page number
        :param int per_page: allows you to specify a page size up to 100 items, 25 by default
        :param str branch: specify the branch to use
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: list[Upload]
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.uploads_list_with_http_info(project_id, **kwargs)  # noqa: E501

    def uploads_list_with_http_info(self, project_id, **kwargs):  # noqa: E501
        """List uploads  # noqa: E501

        List all uploads for the given project.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.uploads_list_with_http_info(project_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str project_id: Project ID (required)
        :param str x_phrase_app_otp: Two-Factor-Authentication token (optional)
        :param int page: Page number
        :param int per_page: allows you to specify a page size up to 100 items, 25 by default
        :param str branch: specify the branch to use
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(list[Upload], status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'project_id',
            'x_phrase_app_otp',
            'page',
            'per_page',
            'branch'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method uploads_list" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'project_id' is set
        if self.api_client.client_side_validation and ('project_id' not in local_var_params or  # noqa: E501
                                                        local_var_params['project_id'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `project_id` when calling `uploads_list`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'project_id' in local_var_params:
            path_params['project_id'] = local_var_params['project_id']  # noqa: E501

        query_params = []
        if 'page' in local_var_params and local_var_params['page'] is not None:  # noqa: E501
            query_params.append(('page', local_var_params['page']))  # noqa: E501
        if 'per_page' in local_var_params and local_var_params['per_page'] is not None:  # noqa: E501
            query_params.append(('per_page', local_var_params['per_page']))  # noqa: E501
        if 'branch' in local_var_params and local_var_params['branch'] is not None:  # noqa: E501
            query_params.append(('branch', local_var_params['branch']))  # noqa: E501

        header_params = {}
        if 'x_phrase_app_otp' in local_var_params:
            header_params['X-PhraseApp-OTP'] = local_var_params['x_phrase_app_otp']  # noqa: E501

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['Basic', 'Token']  # noqa: E501

        return self.api_client.call_api(
            '/projects/{project_id}/uploads', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='list[Upload]',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)



# coding: utf-8

"""
    Phrase Strings API Reference

    The version of the OpenAPI document: 2.0.0
    Contact: support@phrase.com
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import re  # noqa: F401

# python 2 and python 3 compatibility library
import six

from phrase_api.api_client import ApiClient
from phrase_api.exceptions import (  # noqa: F401
    ApiTypeError,
    ApiValueError
)


class JobsApi(object):
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client

    def job_complete(self, project_id, id, job_complete_parameters, **kwargs):  # noqa: E501
        """Complete a job  # noqa: E501

        Mark a job as completed.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.job_complete(project_id, id, job_complete_parameters, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str project_id: Project ID (required)
        :param str id: ID (required)
        :param JobCompleteParameters job_complete_parameters: (required)
        :param str x_phrase_app_otp: Two-Factor-Authentication token (optional)
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: JobDetails
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.job_complete_with_http_info(project_id, id, job_complete_parameters, **kwargs)  # noqa: E501

    def job_complete_with_http_info(self, project_id, id, job_complete_parameters, **kwargs):  # noqa: E501
        """Complete a job  # noqa: E501

        Mark a job as completed.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.job_complete_with_http_info(project_id, id, job_complete_parameters, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str project_id: Project ID (required)
        :param str id: ID (required)
        :param JobCompleteParameters job_complete_parameters: (required)
        :param str x_phrase_app_otp: Two-Factor-Authentication token (optional)
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(JobDetails, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'project_id',
            'id',
            'job_complete_parameters',
            'x_phrase_app_otp'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method job_complete" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'project_id' is set
        if self.api_client.client_side_validation and ('project_id' not in local_var_params or  # noqa: E501
                                                        local_var_params['project_id'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `project_id` when calling `job_complete`")  # noqa: E501
        # verify the required parameter 'id' is set
        if self.api_client.client_side_validation and ('id' not in local_var_params or  # noqa: E501
                                                        local_var_params['id'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `id` when calling `job_complete`")  # noqa: E501
        # verify the required parameter 'job_complete_parameters' is set
        if self.api_client.client_side_validation and ('job_complete_parameters' not in local_var_params or  # noqa: E501
                                                        local_var_params['job_complete_parameters'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `job_complete_parameters` when calling `job_complete`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'project_id' in local_var_params:
            path_params['project_id'] = local_var_params['project_id']  # noqa: E501
        if 'id' in local_var_params:
            path_params['id'] = local_var_params['id']  # noqa: E501

        query_params = []

        header_params = {}
        if 'x_phrase_app_otp' in local_var_params:
            header_params['X-PhraseApp-OTP'] = local_var_params['x_phrase_app_otp']  # noqa: E501

        form_params = []
        local_var_files = {}

        body_params = None
        if 'job_complete_parameters' in local_var_params:
            body_params = local_var_params['job_complete_parameters']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['Basic', 'Token']  # noqa: E501

        return self.api_client.call_api(
            '/projects/{project_id}/jobs/{id}/complete', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='JobDetails',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def job_create(self, project_id, job_create_parameters, **kwargs):  # noqa: E501
        """Create a job  # noqa: E501

        Create a new job.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.job_create(project_id, job_create_parameters, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str project_id: Project ID (required)
        :param JobCreateParameters job_create_parameters: (required)
        :param str x_phrase_app_otp: Two-Factor-Authentication token (optional)
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: JobDetails
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.job_create_with_http_info(project_id, job_create_parameters, **kwargs)  # noqa: E501

    def job_create_with_http_info(self, project_id, job_create_parameters, **kwargs):  # noqa: E501
        """Create a job  # noqa: E501

        Create a new job.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.job_create_with_http_info(project_id, job_create_parameters, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str project_id: Project ID (required)
        :param JobCreateParameters job_create_parameters: (required)
        :param str x_phrase_app_otp: Two-Factor-Authentication token (optional)
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(JobDetails, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'project_id',
            'job_create_parameters',
            'x_phrase_app_otp'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method job_create" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'project_id' is set
        if self.api_client.client_side_validation and ('project_id' not in local_var_params or  # noqa: E501
                                                        local_var_params['project_id'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `project_id` when calling `job_create`")  # noqa: E501
        # verify the required parameter 'job_create_parameters' is set
        if self.api_client.client_side_validation and ('job_create_parameters' not in local_var_params or  # noqa: E501
                                                        local_var_params['job_create_parameters'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `job_create_parameters` when calling `job_create`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'project_id' in local_var_params:
            path_params['project_id'] = local_var_params['project_id']  # noqa: E501

        query_params = []

        header_params = {}
        if 'x_phrase_app_otp' in local_var_params:
            header_params['X-PhraseApp-OTP'] = local_var_params['x_phrase_app_otp']  # noqa: E501

        form_params = []
        local_var_files = {}

        body_params = None
        if 'job_create_parameters' in local_var_params:
            body_params = local_var_params['job_create_parameters']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['Basic', 'Token']  # noqa: E501

        return self.api_client.call_api(
            '/projects/{project_id}/jobs', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='JobDetails',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def job_delete(self, project_id, id, **kwargs):  # noqa: E501
        """Delete a job  # noqa: E501

        Delete an existing job.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.job_delete(project_id, id, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str project_id: Project ID (required)
        :param str id: ID (required)
        :param str x_phrase_app_otp: Two-Factor-Authentication token (optional)
        :param str branch: specify the branch to use
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.job_delete_with_http_info(project_id, id, **kwargs)  # noqa: E501

    def job_delete_with_http_info(self, project_id, id, **kwargs):  # noqa: E501
        """Delete a job  # noqa: E501

        Delete an existing job.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.job_delete_with_http_info(project_id, id, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str project_id: Project ID (required)
        :param str id: ID (required)
        :param str x_phrase_app_otp: Two-Factor-Authentication token (optional)
        :param str branch: specify the branch to use
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'project_id',
            'id',
            'x_phrase_app_otp',
            'branch'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method job_delete" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'project_id' is set
        if self.api_client.client_side_validation and ('project_id' not in local_var_params or  # noqa: E501
                                                        local_var_params['project_id'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `project_id` when calling `job_delete`")  # noqa: E501
        # verify the required parameter 'id' is set
        if self.api_client.client_side_validation and ('id' not in local_var_params or  # noqa: E501
                                                        local_var_params['id'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `id` when calling `job_delete`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'project_id' in local_var_params:
            path_params['project_id'] = local_var_params['project_id']  # noqa: E501
        if 'id' in local_var_params:
            path_params['id'] = local_var_params['id']  # noqa: E501

        query_params = []
        if 'branch' in local_var_params and local_var_params['branch'] is not None:  # noqa: E501
            query_params.append(('branch', local_var_params['branch']))  # noqa: E501

        header_params = {}
        if 'x_phrase_app_otp' in local_var_params:
            header_params['X-PhraseApp-OTP'] = local_var_params['x_phrase_app_otp']  # noqa: E501

        form_params = []
        local_var_files = {}

        body_params = None
        # Authentication setting
        auth_settings = ['Basic', 'Token']  # noqa: E501

        return self.api_client.call_api(
            '/projects/{project_id}/jobs/{id}', 'DELETE',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type=None,  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def job_keys_create(self, project_id, id, job_keys_create_parameters, **kwargs):  # noqa: E501
        """Add keys to job  # noqa: E501

        Add multiple keys to a existing job.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.job_keys_create(project_id, id, job_keys_create_parameters, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str project_id: Project ID (required)
        :param str id: ID (required)
        :param JobKeysCreateParameters job_keys_create_parameters: (required)
        :param str x_phrase_app_otp: Two-Factor-Authentication token (optional)
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: JobDetails
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.job_keys_create_with_http_info(project_id, id, job_keys_create_parameters, **kwargs)  # noqa: E501

    def job_keys_create_with_http_info(self, project_id, id, job_keys_create_parameters, **kwargs):  # noqa: E501
        """Add keys to job  # noqa: E501

        Add multiple keys to a existing job.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.job_keys_create_with_http_info(project_id, id, job_keys_create_parameters, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str project_id: Project ID (required)
        :param str id: ID (required)
        :param JobKeysCreateParameters job_keys_create_parameters: (required)
        :param str x_phrase_app_otp: Two-Factor-Authentication token (optional)
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(JobDetails, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'project_id',
            'id',
            'job_keys_create_parameters',
            'x_phrase_app_otp'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method job_keys_create" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'project_id' is set
        if self.api_client.client_side_validation and ('project_id' not in local_var_params or  # noqa: E501
                                                        local_var_params['project_id'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `project_id` when calling `job_keys_create`")  # noqa: E501
        # verify the required parameter 'id' is set
        if self.api_client.client_side_validation and ('id' not in local_var_params or  # noqa: E501
                                                        local_var_params['id'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `id` when calling `job_keys_create`")  # noqa: E501
        # verify the required parameter 'job_keys_create_parameters' is set
        if self.api_client.client_side_validation and ('job_keys_create_parameters' not in local_var_params or  # noqa: E501
                                                        local_var_params['job_keys_create_parameters'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `job_keys_create_parameters` when calling `job_keys_create`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'project_id' in local_var_params:
            path_params['project_id'] = local_var_params['project_id']  # noqa: E501
        if 'id' in local_var_params:
            path_params['id'] = local_var_params['id']  # noqa: E501

        query_params = []

        header_params = {}
        if 'x_phrase_app_otp' in local_var_params:
            header_params['X-PhraseApp-OTP'] = local_var_params['x_phrase_app_otp']  # noqa: E501

        form_params = []
        local_var_files = {}

        body_params = None
        if 'job_keys_create_parameters' in local_var_params:
            body_params = local_var_params['job_keys_create_parameters']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['Basic', 'Token']  # noqa: E501

        return self.api_client.call_api(
            '/projects/{project_id}/jobs/{id}/keys', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='JobDetails',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def job_keys_delete(self, project_id, id, **kwargs):  # noqa: E501
        """Remove keys from job  # noqa: E501

        Remove multiple keys from existing job.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.job_keys_delete(project_id, id, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str project_id: Project ID (required)
        :param str id: ID (required)
        :param str x_phrase_app_otp: Two-Factor-Authentication token (optional)
        :param str branch: specify the branch to use
        :param list[str] translation_key_ids: ids of keys that should added to the job
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.job_keys_delete_with_http_info(project_id, id, **kwargs)  # noqa: E501

    def job_keys_delete_with_http_info(self, project_id, id, **kwargs):  # noqa: E501
        """Remove keys from job  # noqa: E501

        Remove multiple keys from existing job.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.job_keys_delete_with_http_info(project_id, id, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str project_id: Project ID (required)
        :param str id: ID (required)
        :param str x_phrase_app_otp: Two-Factor-Authentication token (optional)
        :param str branch: specify the branch to use
        :param list[str] translation_key_ids: ids of keys that should added to the job
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'project_id',
            'id',
            'x_phrase_app_otp',
            'branch',
            'translation_key_ids'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method job_keys_delete" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'project_id' is set
        if self.api_client.client_side_validation and ('project_id' not in local_var_params or  # noqa: E501
                                                        local_var_params['project_id'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `project_id` when calling `job_keys_delete`")  # noqa: E501
        # verify the required parameter 'id' is set
        if self.api_client.client_side_validation and ('id' not in local_var_params or  # noqa: E501
                                                        local_var_params['id'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `id` when calling `job_keys_delete`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'project_id' in local_var_params:
            path_params['project_id'] = local_var_params['project_id']  # noqa: E501
        if 'id' in local_var_params:
            path_params['id'] = local_var_params['id']  # noqa: E501

        query_params = []
        if 'branch' in local_var_params and local_var_params['branch'] is not None:  # noqa: E501
            query_params.append(('branch', local_var_params['branch']))  # noqa: E501
        if 'translation_key_ids' in local_var_params and local_var_params['translation_key_ids'] is not None:  # noqa: E501
            query_params.append(('translation_key_ids', local_var_params['translation_key_ids']))  # noqa: E501
            collection_formats['translation_key_ids'] = 'multi'  # noqa: E501

        header_params = {}
        if 'x_phrase_app_otp' in local_var_params:
            header_params['X-PhraseApp-OTP'] = local_var_params['x_phrase_app_otp']  # noqa: E501

        form_params = []
        local_var_files = {}

        body_params = None
        # Authentication setting
        auth_settings = ['Basic', 'Token']  # noqa: E501

        return self.api_client.call_api(
            '/projects/{project_id}/jobs/{id}/keys', 'DELETE',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type=None,  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def job_lock(self, project_id, id, **kwargs):  # noqa: E501
        """Lock a job  # noqa: E501

        If you are the job owner, you may lock a job using this API request.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.job_lock(project_id, id, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str project_id: Project ID (required)
        :param str id: ID (required)
        :param str x_phrase_app_otp: Two-Factor-Authentication token (optional)
        :param str branch: specify the branch to use
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.job_lock_with_http_info(project_id, id, **kwargs)  # noqa: E501

    def job_lock_with_http_info(self, project_id, id, **kwargs):  # noqa: E501
        """Lock a job  # noqa: E501

        If you are the job owner, you may lock a job using this API request.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.job_lock_with_http_info(project_id, id, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str project_id: Project ID (required)
        :param str id: ID (required)
        :param str x_phrase_app_otp: Two-Factor-Authentication token (optional)
        :param str branch: specify the branch to use
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'project_id',
            'id',
            'x_phrase_app_otp',
            'branch'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method job_lock" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'project_id' is set
        if self.api_client.client_side_validation and ('project_id' not in local_var_params or  # noqa: E501
                                                        local_var_params['project_id'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `project_id` when calling `job_lock`")  # noqa: E501
        # verify the required parameter 'id' is set
        if self.api_client.client_side_validation and ('id' not in local_var_params or  # noqa: E501
                                                        local_var_params['id'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `id` when calling `job_lock`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'project_id' in local_var_params:
            path_params['project_id'] = local_var_params['project_id']  # noqa: E501
        if 'id' in local_var_params:
            path_params['id'] = local_var_params['id']  # noqa: E501

        query_params = []
        if 'branch' in local_var_params and local_var_params['branch'] is not None:  # noqa: E501
            query_params.append(('branch', local_var_params['branch']))  # noqa: E501

        header_params = {}
        if 'x_phrase_app_otp' in local_var_params:
            header_params['X-PhraseApp-OTP'] = local_var_params['x_phrase_app_otp']  # noqa: E501

        form_params = []
        local_var_files = {}

        body_params = None
        # Authentication setting
        auth_settings = ['Basic', 'Token']  # noqa: E501

        return self.api_client.call_api(
            '/projects/{project_id}/jobs/{id}/lock', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type=None,  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def job_reopen(self, project_id, id, job_reopen_parameters, **kwargs):  # noqa: E501
        """Reopen a job  # noqa: E501

        Mark a job as uncompleted.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.job_reopen(project_id, id, job_reopen_parameters, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str project_id: Project ID (required)
        :param str id: ID (required)
        :param JobReopenParameters job_reopen_parameters: (required)
        :param str x_phrase_app_otp: Two-Factor-Authentication token (optional)
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: JobDetails
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.job_reopen_with_http_info(project_id, id, job_reopen_parameters, **kwargs)  # noqa: E501

    def job_reopen_with_http_info(self, project_id, id, job_reopen_parameters, **kwargs):  # noqa: E501
        """Reopen a job  # noqa: E501

        Mark a job as uncompleted.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.job_reopen_with_http_info(project_id, id, job_reopen_parameters, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str project_id: Project ID (required)
        :param str id: ID (required)
        :param JobReopenParameters job_reopen_parameters: (required)
        :param str x_phrase_app_otp: Two-Factor-Authentication token (optional)
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(JobDetails, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'project_id',
            'id',
            'job_reopen_parameters',
            'x_phrase_app_otp'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method job_reopen" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'project_id' is set
        if self.api_client.client_side_validation and ('project_id' not in local_var_params or  # noqa: E501
                                                        local_var_params['project_id'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `project_id` when calling `job_reopen`")  # noqa: E501
        # verify the required parameter 'id' is set
        if self.api_client.client_side_validation and ('id' not in local_var_params or  # noqa: E501
                                                        local_var_params['id'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `id` when calling `job_reopen`")  # noqa: E501
        # verify the required parameter 'job_reopen_parameters' is set
        if self.api_client.client_side_validation and ('job_reopen_parameters' not in local_var_params or  # noqa: E501
                                                        local_var_params['job_reopen_parameters'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `job_reopen_parameters` when calling `job_reopen`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'project_id' in local_var_params:
            path_params['project_id'] = local_var_params['project_id']  # noqa: E501
        if 'id' in local_var_params:
            path_params['id'] = local_var_params['id']  # noqa: E501

        query_params = []

        header_params = {}
        if 'x_phrase_app_otp' in local_var_params:
            header_params['X-PhraseApp-OTP'] = local_var_params['x_phrase_app_otp']  # noqa: E501

        form_params = []
        local_var_files = {}

        body_params = None
        if 'job_reopen_parameters' in local_var_params:
            body_params = local_var_params['job_reopen_parameters']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['Basic', 'Token']  # noqa: E501

        return self.api_client.call_api(
            '/projects/{project_id}/jobs/{id}/reopen', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='JobDetails',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def job_show(self, project_id, id, **kwargs):  # noqa: E501
        """Get a single job  # noqa: E501

        Get details on a single job for a given project.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.job_show(project_id, id, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str project_id: Project ID (required)
        :param str id: ID (required)
        :param str x_phrase_app_otp: Two-Factor-Authentication token (optional)
        :param str branch: specify the branch to use
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: JobDetails
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.job_show_with_http_info(project_id, id, **kwargs)  # noqa: E501

    def job_show_with_http_info(self, project_id, id, **kwargs):  # noqa: E501
        """Get a single job  # noqa: E501

        Get details on a single job for a given project.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.job_show_with_http_info(project_id, id, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str project_id: Project ID (required)
        :param str id: ID (required)
        :param str x_phrase_app_otp: Two-Factor-Authentication token (optional)
        :param str branch: specify the branch to use
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(JobDetails, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'project_id',
            'id',
            'x_phrase_app_otp',
            'branch'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method job_show" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'project_id' is set
        if self.api_client.client_side_validation and ('project_id' not in local_var_params or  # noqa: E501
                                                        local_var_params['project_id'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `project_id` when calling `job_show`")  # noqa: E501
        # verify the required parameter 'id' is set
        if self.api_client.client_side_validation and ('id' not in local_var_params or  # noqa: E501
                                                        local_var_params['id'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `id` when calling `job_show`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'project_id' in local_var_params:
            path_params['project_id'] = local_var_params['project_id']  # noqa: E501
        if 'id' in local_var_params:
            path_params['id'] = local_var_params['id']  # noqa: E501

        query_params = []
        if 'branch' in local_var_params and local_var_params['branch'] is not None:  # noqa: E501
            query_params.append(('branch', local_var_params['branch']))  # noqa: E501

        header_params = {}
        if 'x_phrase_app_otp' in local_var_params:
            header_params['X-PhraseApp-OTP'] = local_var_params['x_phrase_app_otp']  # noqa: E501

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['Basic', 'Token']  # noqa: E501

        return self.api_client.call_api(
            '/projects/{project_id}/jobs/{id}', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='JobDetails',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def job_start(self, project_id, id, job_start_parameters, **kwargs):  # noqa: E501
        """Start a job  # noqa: E501

        Starts an existing job in state draft.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.job_start(project_id, id, job_start_parameters, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str project_id: Project ID (required)
        :param str id: ID (required)
        :param JobStartParameters job_start_parameters: (required)
        :param str x_phrase_app_otp: Two-Factor-Authentication token (optional)
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: JobDetails
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.job_start_with_http_info(project_id, id, job_start_parameters, **kwargs)  # noqa: E501

    def job_start_with_http_info(self, project_id, id, job_start_parameters, **kwargs):  # noqa: E501
        """Start a job  # noqa: E501

        Starts an existing job in state draft.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.job_start_with_http_info(project_id, id, job_start_parameters, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str project_id: Project ID (required)
        :param str id: ID (required)
        :param JobStartParameters job_start_parameters: (required)
        :param str x_phrase_app_otp: Two-Factor-Authentication token (optional)
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(JobDetails, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'project_id',
            'id',
            'job_start_parameters',
            'x_phrase_app_otp'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method job_start" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'project_id' is set
        if self.api_client.client_side_validation and ('project_id' not in local_var_params or  # noqa: E501
                                                        local_var_params['project_id'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `project_id` when calling `job_start`")  # noqa: E501
        # verify the required parameter 'id' is set
        if self.api_client.client_side_validation and ('id' not in local_var_params or  # noqa: E501
                                                        local_var_params['id'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `id` when calling `job_start`")  # noqa: E501
        # verify the required parameter 'job_start_parameters' is set
        if self.api_client.client_side_validation and ('job_start_parameters' not in local_var_params or  # noqa: E501
                                                        local_var_params['job_start_parameters'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `job_start_parameters` when calling `job_start`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'project_id' in local_var_params:
            path_params['project_id'] = local_var_params['project_id']  # noqa: E501
        if 'id' in local_var_params:
            path_params['id'] = local_var_params['id']  # noqa: E501

        query_params = []

        header_params = {}
        if 'x_phrase_app_otp' in local_var_params:
            header_params['X-PhraseApp-OTP'] = local_var_params['x_phrase_app_otp']  # noqa: E501

        form_params = []
        local_var_files = {}

        body_params = None
        if 'job_start_parameters' in local_var_params:
            body_params = local_var_params['job_start_parameters']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['Basic', 'Token']  # noqa: E501

        return self.api_client.call_api(
            '/projects/{project_id}/jobs/{id}/start', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='JobDetails',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def job_unlock(self, project_id, id, **kwargs):  # noqa: E501
        """Unlock a job  # noqa: E501

        If you are the job owner, you may unlock a locked job using this API request.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.job_unlock(project_id, id, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str project_id: Project ID (required)
        :param str id: ID (required)
        :param str x_phrase_app_otp: Two-Factor-Authentication token (optional)
        :param str branch: specify the branch to use
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.job_unlock_with_http_info(project_id, id, **kwargs)  # noqa: E501

    def job_unlock_with_http_info(self, project_id, id, **kwargs):  # noqa: E501
        """Unlock a job  # noqa: E501

        If you are the job owner, you may unlock a locked job using this API request.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.job_unlock_with_http_info(project_id, id, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str project_id: Project ID (required)
        :param str id: ID (required)
        :param str x_phrase_app_otp: Two-Factor-Authentication token (optional)
        :param str branch: specify the branch to use
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'project_id',
            'id',
            'x_phrase_app_otp',
            'branch'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method job_unlock" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'project_id' is set
        if self.api_client.client_side_validation and ('project_id' not in local_var_params or  # noqa: E501
                                                        local_var_params['project_id'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `project_id` when calling `job_unlock`")  # noqa: E501
        # verify the required parameter 'id' is set
        if self.api_client.client_side_validation and ('id' not in local_var_params or  # noqa: E501
                                                        local_var_params['id'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `id` when calling `job_unlock`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'project_id' in local_var_params:
            path_params['project_id'] = local_var_params['project_id']  # noqa: E501
        if 'id' in local_var_params:
            path_params['id'] = local_var_params['id']  # noqa: E501

        query_params = []
        if 'branch' in local_var_params and local_var_params['branch'] is not None:  # noqa: E501
            query_params.append(('branch', local_var_params['branch']))  # noqa: E501

        header_params = {}
        if 'x_phrase_app_otp' in local_var_params:
            header_params['X-PhraseApp-OTP'] = local_var_params['x_phrase_app_otp']  # noqa: E501

        form_params = []
        local_var_files = {}

        body_params = None
        # Authentication setting
        auth_settings = ['Basic', 'Token']  # noqa: E501

        return self.api_client.call_api(
            '/projects/{project_id}/jobs/{id}/unlock', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type=None,  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def job_update(self, project_id, id, job_update_parameters, **kwargs):  # noqa: E501
        """Update a job  # noqa: E501

        Update an existing job.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.job_update(project_id, id, job_update_parameters, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str project_id: Project ID (required)
        :param str id: ID (required)
        :param JobUpdateParameters job_update_parameters: (required)
        :param str x_phrase_app_otp: Two-Factor-Authentication token (optional)
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: JobDetails
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.job_update_with_http_info(project_id, id, job_update_parameters, **kwargs)  # noqa: E501

    def job_update_with_http_info(self, project_id, id, job_update_parameters, **kwargs):  # noqa: E501
        """Update a job  # noqa: E501

        Update an existing job.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.job_update_with_http_info(project_id, id, job_update_parameters, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str project_id: Project ID (required)
        :param str id: ID (required)
        :param JobUpdateParameters job_update_parameters: (required)
        :param str x_phrase_app_otp: Two-Factor-Authentication token (optional)
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(JobDetails, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'project_id',
            'id',
            'job_update_parameters',
            'x_phrase_app_otp'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method job_update" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'project_id' is set
        if self.api_client.client_side_validation and ('project_id' not in local_var_params or  # noqa: E501
                                                        local_var_params['project_id'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `project_id` when calling `job_update`")  # noqa: E501
        # verify the required parameter 'id' is set
        if self.api_client.client_side_validation and ('id' not in local_var_params or  # noqa: E501
                                                        local_var_params['id'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `id` when calling `job_update`")  # noqa: E501
        # verify the required parameter 'job_update_parameters' is set
        if self.api_client.client_side_validation and ('job_update_parameters' not in local_var_params or  # noqa: E501
                                                        local_var_params['job_update_parameters'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `job_update_parameters` when calling `job_update`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'project_id' in local_var_params:
            path_params['project_id'] = local_var_params['project_id']  # noqa: E501
        if 'id' in local_var_params:
            path_params['id'] = local_var_params['id']  # noqa: E501

        query_params = []

        header_params = {}
        if 'x_phrase_app_otp' in local_var_params:
            header_params['X-PhraseApp-OTP'] = local_var_params['x_phrase_app_otp']  # noqa: E501

        form_params = []
        local_var_files = {}

        body_params = None
        if 'job_update_parameters' in local_var_params:
            body_params = local_var_params['job_update_parameters']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['Basic', 'Token']  # noqa: E501

        return self.api_client.call_api(
            '/projects/{project_id}/jobs/{id}', 'PATCH',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='JobDetails',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def jobs_by_account(self, account_id, **kwargs):  # noqa: E501
        """List account jobs  # noqa: E501

        List all jobs for the given account.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.jobs_by_account(account_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str account_id: Account ID (required)
        :param str x_phrase_app_otp: Two-Factor-Authentication token (optional)
        :param int page: Page number
        :param int per_page: allows you to specify a page size up to 100 items, 25 by default
        :param str owned_by: filter by user owning job
        :param str assigned_to: filter by user assigned to job
        :param str state: filter by state of job Valid states are <code>draft</code>, <code>in_progress</code>, <code>completed</code>
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: list[Job]
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.jobs_by_account_with_http_info(account_id, **kwargs)  # noqa: E501

    def jobs_by_account_with_http_info(self, account_id, **kwargs):  # noqa: E501
        """List account jobs  # noqa: E501

        List all jobs for the given account.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.jobs_by_account_with_http_info(account_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str account_id: Account ID (required)
        :param str x_phrase_app_otp: Two-Factor-Authentication token (optional)
        :param int page: Page number
        :param int per_page: allows you to specify a page size up to 100 items, 25 by default
        :param str owned_by: filter by user owning job
        :param str assigned_to: filter by user assigned to job
        :param str state: filter by state of job Valid states are <code>draft</code>, <code>in_progress</code>, <code>completed</code>
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(list[Job], status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'account_id',
            'x_phrase_app_otp',
            'page',
            'per_page',
            'owned_by',
            'assigned_to',
            'state'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method jobs_by_account" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'account_id' is set
        if self.api_client.client_side_validation and ('account_id' not in local_var_params or  # noqa: E501
                                                        local_var_params['account_id'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `account_id` when calling `jobs_by_account`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'account_id' in local_var_params:
            path_params['account_id'] = local_var_params['account_id']  # noqa: E501

        query_params = []
        if 'page' in local_var_params and local_var_params['page'] is not None:  # noqa: E501
            query_params.append(('page', local_var_params['page']))  # noqa: E501
        if 'per_page' in local_var_params and local_var_params['per_page'] is not None:  # noqa: E501
            query_params.append(('per_page', local_var_params['per_page']))  # noqa: E501
        if 'owned_by' in local_var_params and local_var_params['owned_by'] is not None:  # noqa: E501
            query_params.append(('owned_by', local_var_params['owned_by']))  # noqa: E501
        if 'assigned_to' in local_var_params and local_var_params['assigned_to'] is not None:  # noqa: E501
            query_params.append(('assigned_to', local_var_params['assigned_to']))  # noqa: E501
        if 'state' in local_var_params and local_var_params['state'] is not None:  # noqa: E501
            query_params.append(('state', local_var_params['state']))  # noqa: E501

        header_params = {}
        if 'x_phrase_app_otp' in local_var_params:
            header_params['X-PhraseApp-OTP'] = local_var_params['x_phrase_app_otp']  # noqa: E501

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['Basic', 'Token']  # noqa: E501

        return self.api_client.call_api(
            '/accounts/{account_id}/jobs', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='list[Job]',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def jobs_list(self, project_id, **kwargs):  # noqa: E501
        """List jobs  # noqa: E501

        List all jobs for the given project.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.jobs_list(project_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str project_id: Project ID (required)
        :param str x_phrase_app_otp: Two-Factor-Authentication token (optional)
        :param int page: Page number
        :param int per_page: allows you to specify a page size up to 100 items, 25 by default
        :param str branch: specify the branch to use
        :param str owned_by: filter by user owning job
        :param str assigned_to: filter by user assigned to job
        :param str state: filter by state of job Valid states are <code>draft</code>, <code>in_progress</code>, <code>completed</code>
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: list[Job]
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.jobs_list_with_http_info(project_id, **kwargs)  # noqa: E501

    def jobs_list_with_http_info(self, project_id, **kwargs):  # noqa: E501
        """List jobs  # noqa: E501

        List all jobs for the given project.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.jobs_list_with_http_info(project_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str project_id: Project ID (required)
        :param str x_phrase_app_otp: Two-Factor-Authentication token (optional)
        :param int page: Page number
        :param int per_page: allows you to specify a page size up to 100 items, 25 by default
        :param str branch: specify the branch to use
        :param str owned_by: filter by user owning job
        :param str assigned_to: filter by user assigned to job
        :param str state: filter by state of job Valid states are <code>draft</code>, <code>in_progress</code>, <code>completed</code>
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(list[Job], status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'project_id',
            'x_phrase_app_otp',
            'page',
            'per_page',
            'branch',
            'owned_by',
            'assigned_to',
            'state'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method jobs_list" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'project_id' is set
        if self.api_client.client_side_validation and ('project_id' not in local_var_params or  # noqa: E501
                                                        local_var_params['project_id'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `project_id` when calling `jobs_list`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'project_id' in local_var_params:
            path_params['project_id'] = local_var_params['project_id']  # noqa: E501

        query_params = []
        if 'page' in local_var_params and local_var_params['page'] is not None:  # noqa: E501
            query_params.append(('page', local_var_params['page']))  # noqa: E501
        if 'per_page' in local_var_params and local_var_params['per_page'] is not None:  # noqa: E501
            query_params.append(('per_page', local_var_params['per_page']))  # noqa: E501
        if 'branch' in local_var_params and local_var_params['branch'] is not None:  # noqa: E501
            query_params.append(('branch', local_var_params['branch']))  # noqa: E501
        if 'owned_by' in local_var_params and local_var_params['owned_by'] is not None:  # noqa: E501
            query_params.append(('owned_by', local_var_params['owned_by']))  # noqa: E501
        if 'assigned_to' in local_var_params and local_var_params['assigned_to'] is not None:  # noqa: E501
            query_params.append(('assigned_to', local_var_params['assigned_to']))  # noqa: E501
        if 'state' in local_var_params and local_var_params['state'] is not None:  # noqa: E501
            query_params.append(('state', local_var_params['state']))  # noqa: E501

        header_params = {}
        if 'x_phrase_app_otp' in local_var_params:
            header_params['X-PhraseApp-OTP'] = local_var_params['x_phrase_app_otp']  # noqa: E501

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['Basic', 'Token']  # noqa: E501

        return self.api_client.call_api(
            '/projects/{project_id}/jobs', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='list[Job]',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)



# coding: utf-8

"""
    Phrase Strings API Reference

    The version of the OpenAPI document: 2.0.0
    Contact: support@phrase.com
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest

import phrase_api
from phrase_api.api.git_lab_sync_api import GitLabSyncApi  # noqa: E501
from phrase_api.rest import ApiException


class TestGitLabSyncApi(unittest.TestCase):
    """GitLabSyncApi unit test stubs"""

    def setUp(self):
        self.api = phrase_api.api.git_lab_sync_api.GitLabSyncApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_gitlab_sync_delete(self):
        """Test case for gitlab_sync_delete

        Delete single Sync Setting  # noqa: E501
        """
        pass

    def test_gitlab_sync_export(self):
        """Test case for gitlab_sync_export

        Export from Phrase Strings to GitLab  # noqa: E501
        """
        pass

    def test_gitlab_sync_history(self):
        """Test case for gitlab_sync_history

        History of single Sync Setting  # noqa: E501
        """
        pass

    def test_gitlab_sync_import(self):
        """Test case for gitlab_sync_import

        Import from GitLab to Phrase  # noqa: E501
        """
        pass

    def test_gitlab_sync_list(self):
        """Test case for gitlab_sync_list

        List GitLab syncs  # noqa: E501
        """
        pass

    def test_gitlab_sync_show(self):
        """Test case for gitlab_sync_show

        Get single Sync Setting  # noqa: E501
        """
        pass

    def test_gitlab_sync_update(self):
        """Test case for gitlab_sync_update

        Update single Sync Setting  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Phrase Strings API Reference

    The version of the OpenAPI document: 2.0.0
    Contact: support@phrase.com
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from phrase_api.configuration import Configuration


class OrderCreateParameters(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'branch': 'str',
        'name': 'str',
        'lsp': 'str',
        'source_locale_id': 'str',
        'target_locale_ids': 'list[str]',
        'translation_type': 'str',
        'tag': 'str',
        'message': 'str',
        'styleguide_id': 'str',
        'unverify_translations_upon_delivery': 'bool',
        'include_untranslated_keys': 'bool',
        'include_unverified_translations': 'bool',
        'category': 'str',
        'quality': 'bool',
        'priority': 'bool'
    }

    attribute_map = {
        'branch': 'branch',
        'name': 'name',
        'lsp': 'lsp',
        'source_locale_id': 'source_locale_id',
        'target_locale_ids': 'target_locale_ids',
        'translation_type': 'translation_type',
        'tag': 'tag',
        'message': 'message',
        'styleguide_id': 'styleguide_id',
        'unverify_translations_upon_delivery': 'unverify_translations_upon_delivery',
        'include_untranslated_keys': 'include_untranslated_keys',
        'include_unverified_translations': 'include_unverified_translations',
        'category': 'category',
        'quality': 'quality',
        'priority': 'priority'
    }

    def __init__(self, branch=None, name=None, lsp=None, source_locale_id=None, target_locale_ids=None, translation_type=None, tag=None, message=None, styleguide_id=None, unverify_translations_upon_delivery=None, include_untranslated_keys=None, include_unverified_translations=None, category=None, quality=None, priority=None, local_vars_configuration=None):  # noqa: E501
        """OrderCreateParameters - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._branch = None
        self._name = None
        self._lsp = None
        self._source_locale_id = None
        self._target_locale_ids = None
        self._translation_type = None
        self._tag = None
        self._message = None
        self._styleguide_id = None
        self._unverify_translations_upon_delivery = None
        self._include_untranslated_keys = None
        self._include_unverified_translations = None
        self._category = None
        self._quality = None
        self._priority = None
        self.discriminator = None

        if branch is not None:
            self.branch = branch
        if name is not None:
            self.name = name
        if lsp is not None:
            self.lsp = lsp
        if source_locale_id is not None:
            self.source_locale_id = source_locale_id
        if target_locale_ids is not None:
            self.target_locale_ids = target_locale_ids
        if translation_type is not None:
            self.translation_type = translation_type
        if tag is not None:
            self.tag = tag
        if message is not None:
            self.message = message
        if styleguide_id is not None:
            self.styleguide_id = styleguide_id
        if unverify_translations_upon_delivery is not None:
            self.unverify_translations_upon_delivery = unverify_translations_upon_delivery
        if include_untranslated_keys is not None:
            self.include_untranslated_keys = include_untranslated_keys
        if include_unverified_translations is not None:
            self.include_unverified_translations = include_unverified_translations
        if category is not None:
            self.category = category
        if quality is not None:
            self.quality = quality
        if priority is not None:
            self.priority = priority

    @property
    def branch(self):
        """Gets the branch of this OrderCreateParameters.  # noqa: E501

        specify the branch to use  # noqa: E501

        :return: The branch of this OrderCreateParameters.  # noqa: E501
        :rtype: str
        """
        return self._branch

    @branch.setter
    def branch(self, branch):
        """Sets the branch of this OrderCreateParameters.

        specify the branch to use  # noqa: E501

        :param branch: The branch of this OrderCreateParameters.  # noqa: E501
        :type: str
        """

        self._branch = branch

    @property
    def name(self):
        """Gets the name of this OrderCreateParameters.  # noqa: E501

        the name of the order, default name is: Translation order from 'current datetime'  # noqa: E501

        :return: The name of this OrderCreateParameters.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this OrderCreateParameters.

        the name of the order, default name is: Translation order from 'current datetime'  # noqa: E501

        :param name: The name of this OrderCreateParameters.  # noqa: E501
        :type: str
        """

        self._name = name

    @property
    def lsp(self):
        """Gets the lsp of this OrderCreateParameters.  # noqa: E501

        Name of the LSP that should process this order. Can be one of gengo, textmaster.  # noqa: E501

        :return: The lsp of this OrderCreateParameters.  # noqa: E501
        :rtype: str
        """
        return self._lsp

    @lsp.setter
    def lsp(self, lsp):
        """Sets the lsp of this OrderCreateParameters.

        Name of the LSP that should process this order. Can be one of gengo, textmaster.  # noqa: E501

        :param lsp: The lsp of this OrderCreateParameters.  # noqa: E501
        :type: str
        """

        self._lsp = lsp

    @property
    def source_locale_id(self):
        """Gets the source_locale_id of this OrderCreateParameters.  # noqa: E501

        Source locale for the order. Can be the name or public id of the source locale. Preferred is the public id.  # noqa: E501

        :return: The source_locale_id of this OrderCreateParameters.  # noqa: E501
        :rtype: str
        """
        return self._source_locale_id

    @source_locale_id.setter
    def source_locale_id(self, source_locale_id):
        """Sets the source_locale_id of this OrderCreateParameters.

        Source locale for the order. Can be the name or public id of the source locale. Preferred is the public id.  # noqa: E501

        :param source_locale_id: The source_locale_id of this OrderCreateParameters.  # noqa: E501
        :type: str
        """

        self._source_locale_id = source_locale_id

    @property
    def target_locale_ids(self):
        """Gets the target_locale_ids of this OrderCreateParameters.  # noqa: E501

        List of target locales you want the source content translate to. Can be the name or public id of the target locales. Preferred is the public id.  # noqa: E501

        :return: The target_locale_ids of this OrderCreateParameters.  # noqa: E501
        :rtype: list[str]
        """
        return self._target_locale_ids

    @target_locale_ids.setter
    def target_locale_ids(self, target_locale_ids):
        """Sets the target_locale_ids of this OrderCreateParameters.

        List of target locales you want the source content translate to. Can be the name or public id of the target locales. Preferred is the public id.  # noqa: E501

        :param target_locale_ids: The target_locale_ids of this OrderCreateParameters.  # noqa: E501
        :type: list[str]
        """

        self._target_locale_ids = target_locale_ids

    @property
    def translation_type(self):
        """Gets the translation_type of this OrderCreateParameters.  # noqa: E501

        Name of the quality level, availability depends on the LSP. Can be one of:  standard, pro (for orders processed by Gengo) and one of regular, premium, enterprise (for orders processed by TextMaster)  # noqa: E501

        :return: The translation_type of this OrderCreateParameters.  # noqa: E501
        :rtype: str
        """
        return self._translation_type

    @translation_type.setter
    def translation_type(self, translation_type):
        """Sets the translation_type of this OrderCreateParameters.

        Name of the quality level, availability depends on the LSP. Can be one of:  standard, pro (for orders processed by Gengo) and one of regular, premium, enterprise (for orders processed by TextMaster)  # noqa: E501

        :param translation_type: The translation_type of this OrderCreateParameters.  # noqa: E501
        :type: str
        """

        self._translation_type = translation_type

    @property
    def tag(self):
        """Gets the tag of this OrderCreateParameters.  # noqa: E501

        Tag you want to order translations for.  # noqa: E501

        :return: The tag of this OrderCreateParameters.  # noqa: E501
        :rtype: str
        """
        return self._tag

    @tag.setter
    def tag(self, tag):
        """Sets the tag of this OrderCreateParameters.

        Tag you want to order translations for.  # noqa: E501

        :param tag: The tag of this OrderCreateParameters.  # noqa: E501
        :type: str
        """

        self._tag = tag

    @property
    def message(self):
        """Gets the message of this OrderCreateParameters.  # noqa: E501

        Message that is displayed to the translators for description.  # noqa: E501

        :return: The message of this OrderCreateParameters.  # noqa: E501
        :rtype: str
        """
        return self._message

    @message.setter
    def message(self, message):
        """Sets the message of this OrderCreateParameters.

        Message that is displayed to the translators for description.  # noqa: E501

        :param message: The message of this OrderCreateParameters.  # noqa: E501
        :type: str
        """

        self._message = message

    @property
    def styleguide_id(self):
        """Gets the styleguide_id of this OrderCreateParameters.  # noqa: E501

        Style guide for translators to be sent with the order.  # noqa: E501

        :return: The styleguide_id of this OrderCreateParameters.  # noqa: E501
        :rtype: str
        """
        return self._styleguide_id

    @styleguide_id.setter
    def styleguide_id(self, styleguide_id):
        """Sets the styleguide_id of this OrderCreateParameters.

        Style guide for translators to be sent with the order.  # noqa: E501

        :param styleguide_id: The styleguide_id of this OrderCreateParameters.  # noqa: E501
        :type: str
        """

        self._styleguide_id = styleguide_id

    @property
    def unverify_translations_upon_delivery(self):
        """Gets the unverify_translations_upon_delivery of this OrderCreateParameters.  # noqa: E501

        Unverify translations upon delivery.  # noqa: E501

        :return: The unverify_translations_upon_delivery of this OrderCreateParameters.  # noqa: E501
        :rtype: bool
        """
        return self._unverify_translations_upon_delivery

    @unverify_translations_upon_delivery.setter
    def unverify_translations_upon_delivery(self, unverify_translations_upon_delivery):
        """Sets the unverify_translations_upon_delivery of this OrderCreateParameters.

        Unverify translations upon delivery.  # noqa: E501

        :param unverify_translations_upon_delivery: The unverify_translations_upon_delivery of this OrderCreateParameters.  # noqa: E501
        :type: bool
        """

        self._unverify_translations_upon_delivery = unverify_translations_upon_delivery

    @property
    def include_untranslated_keys(self):
        """Gets the include_untranslated_keys of this OrderCreateParameters.  # noqa: E501

        Order translations for keys with untranslated content in the selected target locales.  # noqa: E501

        :return: The include_untranslated_keys of this OrderCreateParameters.  # noqa: E501
        :rtype: bool
        """
        return self._include_untranslated_keys

    @include_untranslated_keys.setter
    def include_untranslated_keys(self, include_untranslated_keys):
        """Sets the include_untranslated_keys of this OrderCreateParameters.

        Order translations for keys with untranslated content in the selected target locales.  # noqa: E501

        :param include_untranslated_keys: The include_untranslated_keys of this OrderCreateParameters.  # noqa: E501
        :type: bool
        """

        self._include_untranslated_keys = include_untranslated_keys

    @property
    def include_unverified_translations(self):
        """Gets the include_unverified_translations of this OrderCreateParameters.  # noqa: E501

        Order translations for keys with unverified content in the selected target locales.  # noqa: E501

        :return: The include_unverified_translations of this OrderCreateParameters.  # noqa: E501
        :rtype: bool
        """
        return self._include_unverified_translations

    @include_unverified_translations.setter
    def include_unverified_translations(self, include_unverified_translations):
        """Sets the include_unverified_translations of this OrderCreateParameters.

        Order translations for keys with unverified content in the selected target locales.  # noqa: E501

        :param include_unverified_translations: The include_unverified_translations of this OrderCreateParameters.  # noqa: E501
        :type: bool
        """

        self._include_unverified_translations = include_unverified_translations

    @property
    def category(self):
        """Gets the category of this OrderCreateParameters.  # noqa: E501

        Category to use (required for orders processed by TextMaster).  # noqa: E501

        :return: The category of this OrderCreateParameters.  # noqa: E501
        :rtype: str
        """
        return self._category

    @category.setter
    def category(self, category):
        """Sets the category of this OrderCreateParameters.

        Category to use (required for orders processed by TextMaster).  # noqa: E501

        :param category: The category of this OrderCreateParameters.  # noqa: E501
        :type: str
        """

        self._category = category

    @property
    def quality(self):
        """Gets the quality of this OrderCreateParameters.  # noqa: E501

        Extra proofreading option to ensure consistency in vocabulary and style. Only available for orders processed by TextMaster.  # noqa: E501

        :return: The quality of this OrderCreateParameters.  # noqa: E501
        :rtype: bool
        """
        return self._quality

    @quality.setter
    def quality(self, quality):
        """Sets the quality of this OrderCreateParameters.

        Extra proofreading option to ensure consistency in vocabulary and style. Only available for orders processed by TextMaster.  # noqa: E501

        :param quality: The quality of this OrderCreateParameters.  # noqa: E501
        :type: bool
        """

        self._quality = quality

    @property
    def priority(self):
        """Gets the priority of this OrderCreateParameters.  # noqa: E501

        Indicates whether the priority option should be ordered which decreases turnaround time by 30%. Available only for orders processed by TextMaster.  # noqa: E501

        :return: The priority of this OrderCreateParameters.  # noqa: E501
        :rtype: bool
        """
        return self._priority

    @priority.setter
    def priority(self, priority):
        """Sets the priority of this OrderCreateParameters.

        Indicates whether the priority option should be ordered which decreases turnaround time by 30%. Available only for orders processed by TextMaster.  # noqa: E501

        :param priority: The priority of this OrderCreateParameters.  # noqa: E501
        :type: bool
        """

        self._priority = priority

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, OrderCreateParameters):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, OrderCreateParameters):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Phrase Strings API Reference

    The version of the OpenAPI document: 2.0.0
    Contact: support@phrase.com
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from phrase_api.configuration import Configuration


class JobLocale(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'id': 'str',
        'job': 'JobPreview',
        'locale': 'LocalePreview',
        'users': 'list[UserPreview]',
        'completed': 'bool',
        'translation_completed_at': 'datetime',
        'review_completed_at': 'datetime'
    }

    attribute_map = {
        'id': 'id',
        'job': 'job',
        'locale': 'locale',
        'users': 'users',
        'completed': 'completed',
        'translation_completed_at': 'translation_completed_at',
        'review_completed_at': 'review_completed_at'
    }

    def __init__(self, id=None, job=None, locale=None, users=None, completed=None, translation_completed_at=None, review_completed_at=None, local_vars_configuration=None):  # noqa: E501
        """JobLocale - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._id = None
        self._job = None
        self._locale = None
        self._users = None
        self._completed = None
        self._translation_completed_at = None
        self._review_completed_at = None
        self.discriminator = None

        if id is not None:
            self.id = id
        if job is not None:
            self.job = job
        if locale is not None:
            self.locale = locale
        if users is not None:
            self.users = users
        if completed is not None:
            self.completed = completed
        if translation_completed_at is not None:
            self.translation_completed_at = translation_completed_at
        if review_completed_at is not None:
            self.review_completed_at = review_completed_at

    @property
    def id(self):
        """Gets the id of this JobLocale.  # noqa: E501


        :return: The id of this JobLocale.  # noqa: E501
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this JobLocale.


        :param id: The id of this JobLocale.  # noqa: E501
        :type: str
        """

        self._id = id

    @property
    def job(self):
        """Gets the job of this JobLocale.  # noqa: E501


        :return: The job of this JobLocale.  # noqa: E501
        :rtype: JobPreview
        """
        return self._job

    @job.setter
    def job(self, job):
        """Sets the job of this JobLocale.


        :param job: The job of this JobLocale.  # noqa: E501
        :type: JobPreview
        """

        self._job = job

    @property
    def locale(self):
        """Gets the locale of this JobLocale.  # noqa: E501


        :return: The locale of this JobLocale.  # noqa: E501
        :rtype: LocalePreview
        """
        return self._locale

    @locale.setter
    def locale(self, locale):
        """Sets the locale of this JobLocale.


        :param locale: The locale of this JobLocale.  # noqa: E501
        :type: LocalePreview
        """

        self._locale = locale

    @property
    def users(self):
        """Gets the users of this JobLocale.  # noqa: E501


        :return: The users of this JobLocale.  # noqa: E501
        :rtype: list[UserPreview]
        """
        return self._users

    @users.setter
    def users(self, users):
        """Sets the users of this JobLocale.


        :param users: The users of this JobLocale.  # noqa: E501
        :type: list[UserPreview]
        """

        self._users = users

    @property
    def completed(self):
        """Gets the completed of this JobLocale.  # noqa: E501


        :return: The completed of this JobLocale.  # noqa: E501
        :rtype: bool
        """
        return self._completed

    @completed.setter
    def completed(self, completed):
        """Sets the completed of this JobLocale.


        :param completed: The completed of this JobLocale.  # noqa: E501
        :type: bool
        """

        self._completed = completed

    @property
    def translation_completed_at(self):
        """Gets the translation_completed_at of this JobLocale.  # noqa: E501


        :return: The translation_completed_at of this JobLocale.  # noqa: E501
        :rtype: datetime
        """
        return self._translation_completed_at

    @translation_completed_at.setter
    def translation_completed_at(self, translation_completed_at):
        """Sets the translation_completed_at of this JobLocale.


        :param translation_completed_at: The translation_completed_at of this JobLocale.  # noqa: E501
        :type: datetime
        """

        self._translation_completed_at = translation_completed_at

    @property
    def review_completed_at(self):
        """Gets the review_completed_at of this JobLocale.  # noqa: E501


        :return: The review_completed_at of this JobLocale.  # noqa: E501
        :rtype: datetime
        """
        return self._review_completed_at

    @review_completed_at.setter
    def review_completed_at(self, review_completed_at):
        """Sets the review_completed_at of this JobLocale.


        :param review_completed_at: The review_completed_at of this JobLocale.  # noqa: E501
        :type: datetime
        """

        self._review_completed_at = review_completed_at

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, JobLocale):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, JobLocale):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Phrase Strings API Reference

    The version of the OpenAPI document: 2.0.0
    Contact: support@phrase.com
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest
import datetime

import phrase_api
from phrase_api.models.space1 import Space1  # noqa: E501
from phrase_api.rest import ApiException

class TestSpace1(unittest.TestCase):
    """Space1 unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional):
        """Test Space1
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # model = phrase_api.models.space1.Space1()  # noqa: E501
        if include_optional :
            return Space1(
                id = '0', 
                name = '0', 
                created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                projects_count = 56
            )
        else :
            return Space1(
        )

    def testSpace1(self):
        """Test Space1"""
        inst_req_only = self.make_instance(include_optional=False)
        inst_req_and_optional = self.make_instance(include_optional=True)


if __name__ == '__main__':
    unittest.main()
